#import "template.typ": *

#set page(
  paper: "a6",
  margin: (x: 0.8cm, y: 0.8cm),
)
#set text(
  font: "MonaspiceNe NF",
  size: 4pt,
  fill: bodyColour
)
#set par(
  justify: true,
  leading: 0.52em,
)

#chunk((
  align(center)[
    #text(size: 10pt, weight: "bold", fill: textDarkOrange)[NICK HIEBERT]
  ],
  align(center)[
    #grid(
      columns: (auto, auto, auto),
      gutter: 1em,
      align: horizon,
      contact(
        prefix: "tel:",
        entry: "12049986746",
        display: "1-204-998-6746",
        icon: "assets/phone.svg"
      ),
      contact(
        prefix: "mailto:",
        entry: "nick@upRootNutrition.com",
        display: "nick@upRootNutrition.com",
        icon: "assets/email.svg"
      ),
      contact(
        prefix: "",
        entry: "https://gitlab.com/upRootNutrition",
        display: "gitlab.com/upRootNutrition",
        icon: "assets/gitlab.svg"
      )
    )
  ],
  divider("ABOUT ME"),
  text()[I studied Human Nutritional Science at the #cite("https://umanitoba.ca/", "University of Manitoba"). Though nutrition science is my foremost passion, I cultivated valuable technical skills through self-directed learning in programming, demonstrating my adaptability and commitment to continuous growth. I gained proficiency with several programming languages (#cite("https://nix.dev/manual/nix/2.25/language/", "Nix"), #cite("https://elm-lang.org/", "Elm"), #cite("https://typst.app/", "Typst"), and #cite("https://www.haskell.org/", "Haskell")) while transitioning to the Linux-based operating system #cite("https://nixos.org", "NixOS") and building my own online platform, developing strong problem-solving abilities that complement my scientific background. I bring this same determination and methodical approach to nutrition and food service, where I'm eager to combine my scientific knowledge with my proven ability to tackle complex challenges and quickly acquire new skills.],
  divider("EXPERIENCE"),
  job(
      title: "upRootNutrition",
      position: "Content Creator, Programmer",
      date: "Nov 2018 - Present",
      details: (
        "Developed evidence-based content related to health and nutrition sciences.",
        "Conducted in-depth investigations into nutrition-related research questions for clients.",
        "Mentored clients on nutrition science research methodologies and interpretation.",
        [Managed a 2000+ member #cite("https://discord.gg/eeYQ2wJknS", "Discord") community for engagement and knowledge-sharing.],
        [Curated and maintained a 2000+ reference nutrition literature #cite("https://obsidian.md", "Obsidian") vault.]
      )
    ),
    job(
        title: "De Luca’s",
        position: "Prep Chef, Hot Table Attendant",
        date: "Aug 2018 - June 2019",
        details: (
          "Prepared four-course meals for events ranging from 25-250 people.",
          "Provided customer service and answered questions related to food.",
          "Operated a POS system efficiently and accurately."
        )
      ),
    job(
        title: "The Loft Gastropub",
        position: "Sous Chef",
        date: "June 2013 - Jan 2014",
        details: (
          "Assisted in recipe development and menu planning.",
          "Prepared Italian fusion dishes from scratch, using fresh ingredients.",
          "Consistently resisted the Head Chef’s relentlessly abusive attitude."
        )
      ),
      divider("PROJECTS"),
      job(
        title: "upRootNutrition",
        entry: "https://source.uprootnutrition.com/upRootNutrition/website",
        lines: "35,650",
        position: "Lead Developer",
        date: "2024 - Present",
        lang: (
          "assets/elm.svg",
          "assets/typescript.svg",
          "assets/html.svg",
          "assets/css.svg",
          "assets/haskell.png",
          "assets/nix.svg",
          "assets/markdown.svg"
        ),
        description: [Developed the frontend for my online platform, #cite("https://upRootNutrition.com", "upRootNutrition"), primarily written in the Elm programming language, but also features TypeScript, CSS, and HTML. The project consists of a modular configuration for pages, styling, and data handling. Records, helper functions, and Markdown parsing are organized to make adding new content trivially easy. The project also makes use of a #cite("https://github.com/numtide/devshell", "Devshell") and #cite("https://github.com/direnv/direnv", "Direnv") to create a declarative and reproducible development environment.]
      ),
  divider("PUBLICATIONS"),
  pub(
    author: "Moore, Jeff M., et al.",
    doi: "doi.org/10.1093/cdn/nzac043",
    entry: "https://doi.org/10.1093/cdn/nzac043",
    title: "‘Evidence for a Lean Mass Hyperresponder Phenotype Is Lacking with Increases in LDL Cholesterol of Clinical Significance in All Categories of Response to A-Restricted Diet’. Current Developments in Nutrition, vol. 6, no. 5, May 2022, p. nzac043."
  ),
  divider("EDUCATION"),
  list((
    edu(
      institute: "Studio 11 Inc",
      cert: "Audio Production",
      year: "2008"
    ),
    edu(
      institute: "University of Manitoba",
      cert: "Human Nutritional Science",
      year: "2011"
    ),
    edu(
      institute: "Manitoba Health",
      cert: "Body Modification Technician",
      year: "2023"
    ),
    edu(
      institute: "Canada Safety Training",
      cert: "Bloodborne Pathogen Safety",
      year: "2023"
    ),
    edu(
      institute: "Canadian Red Cross",
      cert: "Preventing Disease Transmission",
      year: "2023"
    ),
  divider("REFERENCES"),
    edu(
      institute: "Available upon request."
    ),
  ))
))
