#let textLightGrey = rgb("#D4D4D4")
#let textDarkGrey = rgb("#7E7E7E")
#let textLightOrange = rgb("#CC6600")
#let textDarkOrange = rgb("#783C00")
#let textDeepDarkOrange = rgb("#3C1E00")
#let backgroundLightGrey = rgb("#282828")
#let backgroundDarkGrey = rgb("#1E1E1E")
#let backgroundDeepDarkGrey = rgb("#141414")
#let shadow = rgb("#0A0A0A")
#let barGreen = rgb("#006600")
#let barRed = rgb("#660000")
#let debugColour = rgb("#E31C79")

#let chunk(content) = {
  stack(
    spacing: 1em,
    ..content
  )
}

#let list(content) = {
  stack(
    spacing: 0.75em,
    ..content
  )
}

#let titlesize = 5.5pt

#let titleColour = textDarkOrange
#let subTitleColour = textDeepDarkOrange
#let bodyColour = backgroundLightGrey
#let linkColour = textLightOrange

#let cite(url, content) = {
  link(url)[#text(fill: linkColour)[#content]]
}

#let contact(prefix: "", entry: "", display: "", icon: "") = {
  let url = prefix + entry
    grid(
      columns: (auto, auto),
      gutter: 0.2em,
      image(icon, height: 1em),
      link(url)[#text(fill: textLightOrange)[#display]]
    )
}

#let divider(title) = {
  pad(y: 0.2em)[
      #grid(
        columns: (1fr, auto, 1fr),
        column-gutter: 1em,
        align: (horizon, horizon, horizon),
        curve(
          stroke: (paint: gradient.linear(textLightOrange, textDarkOrange), thickness: 0.60pt),
          curve.move((0%, 0%)),
          // curve.cubic((25%, 1.5%), (50%, -0.75%), (50%, 0%)),
          // curve.cubic((50%, 0.75%), (75%, -0.75%), (100%, 0%)),
          curve.line((40%, 0%)),
          curve.line((100%, 0%))
        ),
        text(size: 7pt, weight: "bold", fill: titleColour)[#title],
        curve(
          stroke: (paint: gradient.linear(textDarkOrange, textLightOrange), thickness: 0.60pt),
          curve.move((100%, 0%)),
          // curve.cubic((75%, 1.5%), (50%, -0.75%), (50%, 0%)),
          // curve.cubic((50%, 0.75%), (25%, -0.75%), (0%, 0%)),
          curve.line((60%, 0%)),
          curve.line((0%, 0%))
        )
      )
    ]
  }

  #let job(
    title: none,
    position: none,
    entry: none,
    lines: none,
    date: none,
    description: none,
    lang: none,
    details: none,
  ) = {
    if title != none {
      let elements = ()

      elements.push([
        #grid(
          columns: (1fr, auto),
          align: (bottom, bottom),
          {
            if entry != none {
              link(entry)[#text(weight: "bold", size: titlesize, fill: titleColour)[#title]]
            } else {
              text(weight: "bold", size: titlesize, fill: titleColour)[#title]
            }
          },
          if lang != none {
            box(grid(
              columns: (auto,) * lang.len(),
              align: (right,) * lang.len(),
              gutter: 2pt,
              ..lang.map(icon => image(icon, height: 2em))
            ))
          }
        )
      ])

      if position != none or date != none {
        elements.push(
          grid(
            columns: (1fr, auto),
            align: (bottom + left, bottom + right),
            if position != none [#text(style: "italic", fill: textLightOrange)[#position]],
            if date != none [#text(style: "italic", fill: textLightOrange)[#date]]
          )
        )
      }

      if description != none {
        elements.push([#text()[#description]])
      }

      if details != none {
        elements.push(
          pad(left: 1.5em)[
            #list(details.map(detail => [• #detail]))
          ]
        )
      }

      if elements.len() > 0 {
        block(spacing: 0.75em)[
          #stack(
            spacing: 0.75em,
            ..elements
          )
        ]
      }
    }
  }

#let edu(
  institute: "",
  cert: "",
  year: ""
) = {
  block(spacing: 0.75em)[
    #stack(
    spacing: 0.75em,
    [
      #text(weight: "bold",size: titlesize, fill: titleColour)[#institute]
    ],
    [
      #grid(
        columns: (1fr, auto),
        text(fill: textLightOrange)[#cert],
        text(style: "italic", fill: textLightOrange)[#year]
      )
    ]
    )
  ]
}

#let pub(
  author: "",
  entry: "",
  doi: "",
  title: ""
) = {
  block(spacing: 0.75em)[
    #stack(
      spacing: 0.75em,
      [
        #text(weight: "bold",size: titlesize, fill: titleColour)[#author]
        #text(style: "italic", fill: backgroundLightGrey)[#title]
      ],
      [
        #link(entry)[#text(fill: textLightOrange)[#doi]]
      ]
    )
  ]
}
